package com.simuwang.manage.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.simuwang.base.common.support.MybatisPage;
import com.simuwang.base.common.util.DateUtils;
import com.simuwang.base.mapper.daq.CompanyContactInfoMapper;
import com.simuwang.base.mapper.daq.LastCompanyContactInfoMapper;
import com.simuwang.base.pojo.dos.CompanyContactInfoDO;
import com.simuwang.base.pojo.dos.CompanyContactInfoPageDO;
import com.simuwang.base.pojo.dos.LastCompanyContactInfoDO;
import com.simuwang.base.pojo.dto.query.CompanyContactQuery;
import com.simuwang.base.pojo.vo.CompanyContactInfoPageVO;
import com.simuwang.base.pojo.vo.CompanyContactInfoVO;
import com.simuwang.manage.service.CompanyContactService;
import com.simuwang.shiro.utils.UserUtils;
import com.smppw.common.pojo.ResultVo;
import com.smppw.common.pojo.enums.status.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

@Service
public class CompanyContactServiceImpl implements CompanyContactService {

    @Autowired
    private LastCompanyContactInfoMapper lastCompanyContactInfoMapper;

    @Autowired
    private CompanyContactInfoMapper companyContactInfoMapper;

    @Override
    public ResultVo saveCompanyContactInfo(CompanyContactInfoVO companyContactInfoVO) {
        ResultVo vo = new ResultVo(ResultCode.SAVE_SUCCESS.getCode());
        companyContactInfoVO.setUpdateTime(DateUtils.getTime());
        companyContactInfoVO.setIsvalid(1);
        companyContactInfoVO.setCreatorId(UserUtils.getLoginUser().getUserId());
        companyContactInfoVO.setUpdaterId(UserUtils.getLoginUser().getUserId());
        CompanyContactInfoDO companyContactInfoDO = BeanUtil.copyProperties(companyContactInfoVO,CompanyContactInfoDO.class);
        CompanyContactInfoDO oldCompanyContactInfoDO = companyContactInfoMapper.getCompanyContactInfo(companyContactInfoDO.getCompanyId(),DateUtils.format(companyContactInfoDO.getContactDate(), DateUtils.YYYY_MM_DD));
        if(oldCompanyContactInfoDO != null && companyContactInfoVO.getId() == null){
            vo.setData(false);
            vo.setMsg("对接信息已经存在，无需新增");
            return vo;
        }
        if(oldCompanyContactInfoDO == null){
            companyContactInfoVO.setCreateTime(DateUtils.getTime());
            companyContactInfoMapper.insert(companyContactInfoDO);
        }else{
            companyContactInfoDO.setId(oldCompanyContactInfoDO.getId());
            companyContactInfoMapper.updateById(companyContactInfoDO);
        }
        LastCompanyContactInfoDO lastCompanyContactInfoDO = lastCompanyContactInfoMapper.getLastCompanyContactInfoDOByCompanyId(companyContactInfoVO.getCompanyId());
        if (lastCompanyContactInfoDO == null) {
            lastCompanyContactInfoDO = BeanUtil.copyProperties(companyContactInfoDO,LastCompanyContactInfoDO.class);
            lastCompanyContactInfoMapper.insert(lastCompanyContactInfoDO);
        }else{
            String contactDate = companyContactInfoVO.getContactDate();
            if(Objects.requireNonNull(DateUtils.parse(contactDate, DateUtils.YYYY_MM_DD)).compareTo(lastCompanyContactInfoDO.getContactDate()) >= 0){
                companyContactInfoDO.toLastDO(lastCompanyContactInfoDO);
                lastCompanyContactInfoMapper.updateById(lastCompanyContactInfoDO);
            }
        }
        vo.setData(true);
        return vo;
    }

    @Override
    public MybatisPage<CompanyContactInfoPageVO> selectCompanyContactInfoList(CompanyContactQuery companyContactQuery) {
        List<CompanyContactInfoPageDO> contactInformationDOList = companyContactInfoMapper.selectCompanyContactInfoList(companyContactQuery);
        long total = companyContactInfoMapper.countCompanyContactInfo(companyContactQuery);
        List<CompanyContactInfoPageVO> dataList = contactInformationDOList.stream().map(CompanyContactInfoPageDO::toVO).collect(Collectors.toList());
        return MybatisPage.of(total,dataList);
    }
}
